# SSRF Prevention - Official Documentation & Resources

## OWASP References

1. [OWASP A10 2025: Server-Side Request Forgery](https://owasp.org/Top10/A10_2021-Server-Side_Request_Forgery_(SSRF)/)
2. [OWASP SSRF Prevention Cheat Sheet](https://cheatsheetseries.owasp.org/cheatsheets/Server_Side_Request_Forgery_Prevention_Cheat_Sheet.html)
3. [OWASP Top 10 2025 RC1 - SSRF](https://owasp.org/www-project-top-ten/)

## Node.js HTTP Client Security

4. [node-fetch Official Documentation](https://github.com/node-fetch/node-fetch)
5. [Node.js URL API Documentation](https://nodejs.org/api/url.html)
6. [Node.js DNS Module Documentation](https://nodejs.org/api/dns.html)
7. [valid-url npm Package](https://www.npmjs.com/package/valid-url)
8. [check-valid-url npm Package](https://www.npmjs.com/package/check-valid-url)

## Network Security

9. [Private IP Address Ranges (RFC 1918)](https://tools.ietf.org/html/rfc1918)
10. [Multicast Address Allocation (RFC 5771)](https://tools.ietf.org/html/rfc5771)
11. [Link-Local Addresses (RFC 3927)](https://tools.ietf.org/html/rfc3927)

## SSRF Exploitation & Case Studies

12. [Capital One Data Breach (2019) - SSRF via IMDS](https://en.wikipedia.org/wiki/Capital_One_data_breach)
13. [AWS EC2 Instance Metadata Service (IMDS) v2](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configuring-instance-metadata-service.html)
14. [GCP Metadata Server Protection](https://cloud.google.com/docs/metadata/hide-metadata)
15. [Azure Instance Metadata Service](https://learn.microsoft.com/en-us/azure/virtual-machines/windows/instance-metadata-service)

## WAF & IPS Detection

16. [ModSecurity SSRF Rules](https://github.com/coreruleset/coreruleset)
17. [NIST Guidelines on SSRF](https://nvlpubs.nist.gov/nistpubs/SpecialPublications/NIST.SP.800-53r5.pdf)
18. [CWE-918: Server-Side Request Forgery](https://cwe.mitre.org/data/definitions/918.html)

## DNS Rebinding Prevention

19. [DNS Rebinding Attack - Explanation](https://en.wikipedia.org/wiki/DNS_rebinding)
20. [DNS Rebinding Protection in Browsers](https://groups.google.com/a/chromium.org/forum/#!msg/chromium-dev/h2I8WpWpzd4/X68pHTVrMi8J)
21. [Preventing DNS Rebinding Attacks](https://blog.fox-it.com/2015/08/19/dns-rebinding/)

## Context7 MCP Integration

22. [Context7 API Documentation](https://context7.ai/docs)
23. [Context7 Threat Intelligence](https://context7.ai/threat-intelligence)
24. [Context7 SSRF Detection Rules](https://context7.ai/rules/ssrf)

